// Copyright (c) The Geekeey Authors
// SPDX-License-Identifier: EUPL-1.2

using System.Buffers;
using System.Text;

using Spectre.Console.Cli;

namespace Geekeey.Extensions.Process.Tests.Dummy.Commands;

internal sealed class GenerateBlobCommand : AsyncOutputCommand<GenerateBlobCommand.Settings>
{
	private readonly Random _random = new(1234567);

	public sealed class Settings : OutputCommandSettings
	{
		[CommandOption("--length")] public long Length { get; init; } = 100_000;
		[CommandOption("--buffer")] public int BufferSize { get; init; } = 1024;
	}

	public override async Task<int> ExecuteAsync(CommandContext context, Settings settings)
	{
		using var tty = Terminal.Connect();

		using var bytes = MemoryPool<byte>.Shared.Rent(settings.BufferSize);

		var total = 0L;
		while (total < settings.Length)
		{
			_random.NextBytes(bytes.Memory.Span);

			var count = (int)Math.Min(bytes.Memory.Length, settings.Length - total);
			foreach (var writer in tty.GetWriters(settings.Target))
			{
				await writer.BaseStream.WriteAsync(bytes.Memory[..count]);
			}

			total += count;
		}

		return 0;
	}
}