// Copyright (c) The Geekeey Authors
// SPDX-License-Identifier: EUPL-1.2

using System.Buffers;
using System.Globalization;

using Spectre.Console.Cli;

namespace Geekeey.Extensions.Process.Tests.Dummy.Commands;

internal sealed class LengthCommand : AsyncOutputCommand<LengthCommand.Settings>
{
	public sealed class Settings : OutputCommandSettings
	{
	}

	public override async Task<int> ExecuteAsync(CommandContext context, Settings settings)
	{
		using var tty = Terminal.Connect();

		using var buffer = MemoryPool<byte>.Shared.Rent(81920);

		var count = 0L;
		while (true)
		{
			var bytesRead = await tty.Stdin.BaseStream.ReadAsync(buffer.Memory);
			if (bytesRead <= 0)
				break;

			count += bytesRead;
		}

		foreach (var writer in tty.GetWriters(settings.Target))
		{
			await writer.WriteLineAsync(count.ToString(CultureInfo.InvariantCulture));
		}

		return 0;
	}
}