// Copyright (c) The Geekeey Authors
// SPDX-License-Identifier: EUPL-1.2

using Spectre.Console.Cli;

namespace Geekeey.Extensions.Process.Tests.Dummy.Commands;

internal sealed class SleepCommand : AsyncCommand<SleepCommand.Settings>
{
	public sealed class Settings : CommandSettings
	{
		[CommandArgument(0, "[duration]")] public TimeSpan Duration { get; init; } = TimeSpan.FromSeconds(1);
	}

	public override async Task<int> ExecuteAsync(CommandContext context, Settings settings)
	{
		using var tty = Terminal.Connect();

		try
		{
			await Console.Out.WriteLineAsync($"Sleeping for {settings.Duration}...");
			await Console.Out.FlushAsync(CancellationToken.None);

			await Task.Delay(settings.Duration, tty.CancellationToken);
		}
		catch (OperationCanceledException)
		{
			await Console.Out.WriteLineAsync("Canceled.");
			await Console.Out.FlushAsync(CancellationToken.None);
		}

		await Console.Out.WriteLineAsync("Done.");
		await Console.Out.FlushAsync(CancellationToken.None);
		return 0;
	}
}