// Copyright (c) The Geekeey Authors
// SPDX-License-Identifier: EUPL-1.2

namespace Geekeey.Extensions.Process.Tests.Dummy;

internal sealed class Terminal : IDisposable
{
	private readonly CancellationTokenSource _cts = new();

	public Terminal()
	{
		Console.CancelKeyPress += Cancel;
	}

	public StreamReader Stdin { get; } = new(Console.OpenStandardInput(), leaveOpen: false);

	public StreamWriter Stdout { get; } = new(Console.OpenStandardOutput(), leaveOpen: false);

	public StreamWriter Stderr { get; } = new(Console.OpenStandardError(), leaveOpen: false);

	public CancellationToken CancellationToken => _cts.Token;

	public static Terminal Connect()
	{
		return new Terminal();
	}

	private void Cancel(object? sender, ConsoleCancelEventArgs args)
	{
		args.Cancel = true;
		_cts.Cancel();
	}

	public void Dispose()
	{
		Stdout.BaseStream.Flush();
		Stdout.Dispose();
		Stderr.BaseStream.Flush();
		Stderr.Dispose();
		Stdin.Dispose();
		Console.CancelKeyPress -= Cancel;
		_cts.Dispose();
	}
}