// Copyright (c) The Geekeey Authors
// SPDX-License-Identifier: EUPL-1.2

namespace Geekeey.Extensions.Process.Tests;

[TestFixture]
internal sealed class LineBreakTests
{
	private static Command Echo()
		=> new Command(Dummy.Program.FilePath)
			.WithArguments("echo-stdin");

	[Test]
	public async Task I_can_execute_a_command_and_split_the_stdout_by_newline()
	{
		// Arrange
		const string data = "Foo\nBar\nBaz";

		var stdOutLines = new List<string>();

		var cmd = data | Echo() | stdOutLines.Add;

		// Act
		await cmd.ExecuteAsync();

		// Assert
		Assert.That(stdOutLines, Is.EquivalentTo(new[] { "Foo", "Bar", "Baz" }));
	}

	[Test]
	public async Task I_can_execute_a_command_and_split_the_stdout_by_caret_return()
	{
		// Arrange
		const string data = "Foo\rBar\rBaz";

		var stdOutLines = new List<string>();

		var cmd = data | Echo() | stdOutLines.Add;

		// Act
		await cmd.ExecuteAsync();

		// Assert
		Assert.That(stdOutLines, Is.EquivalentTo(new[] { "Foo", "Bar", "Baz" }));
	}

	[Test]
	public async Task I_can_execute_a_command_and_split_the_stdout_by_caret_return_followed_by_newline()
	{
		// Arrange
		const string data = "Foo\r\nBar\r\nBaz";

		var stdOutLines = new List<string>();

		var cmd = data | Echo() | stdOutLines.Add;

		// Act
		await cmd.ExecuteAsync();

		// Assert
		Assert.That(stdOutLines, Is.EquivalentTo(new[] { "Foo", "Bar", "Baz" }));
	}

	[Test]
	public async Task I_can_execute_a_command_and_split_the_stdout_by_newline_while_including_empty_lines()
	{
		// Arrange
		const string data = "Foo\r\rBar\n\nBaz";

		var stdOutLines = new List<string>();

		var cmd = data | Echo() | stdOutLines.Add;

		// Act
		await cmd.ExecuteAsync();

		// Assert
		Assert.That(stdOutLines, Is.EquivalentTo(new[] { "Foo", "", "Bar", "", "Baz" }));
	}
}